@@ -29,8 +29,8 @@
 /* ----------------------------------
  * version info
  * ---------------------------------- */
-static const char man_version[] = "11.67";
-static const char man_date[] = "August 2021";
+static const char man_version[] = "11.68";
+static const char man_date[] = "September 2021";
 
 /* ----------------------------------
  * definitions
